/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kwin.Script.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "scriptadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ScriptAdaptor
 */

ScriptAdaptor::ScriptAdaptor(KWin::AbstractScript *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ScriptAdaptor::~ScriptAdaptor()
{
    // destructor
}

void ScriptAdaptor::run()
{
    // handle method call org.kde.kwin.Script.run
    parent()->run();
}

void ScriptAdaptor::stop()
{
    // handle method call org.kde.kwin.Script.stop
    parent()->stop();
}


#include "moc_scriptadaptor.cpp"
