/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was net.hadess.SensorProxy.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "sensorproxy_interface.h"

/*
 * Implementation of interface class NetHadessSensorProxyInterface
 */

NetHadessSensorProxyInterface::NetHadessSensorProxyInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

NetHadessSensorProxyInterface::~NetHadessSensorProxyInterface()
{
}

/*
 * Implementation of interface class NetHadessSensorProxyCompassInterface
 */

NetHadessSensorProxyCompassInterface::NetHadessSensorProxyCompassInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

NetHadessSensorProxyCompassInterface::~NetHadessSensorProxyCompassInterface()
{
}


#include "moc_sensorproxy_interface.cpp"
