/****************************************************************************
** Meta object code from reading C++ file 'effectsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kwin-6.7.2/src/kcms/common/effectsmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'effectsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KWin12EffectsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KWin::EffectsModel::qt_create_metaobjectdata<qt_meta_tag_ZN4KWin12EffectsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWin::EffectsModel",
        "loaded",
        "",
        "AdditionalRoles",
        "NameRole",
        "DescriptionRole",
        "AuthorNameRole",
        "AuthorEmailRole",
        "LicenseRole",
        "VersionRole",
        "CategoryRole",
        "ServiceNameRole",
        "IconNameRole",
        "StatusRole",
        "WebsiteRole",
        "SupportedRole",
        "ExclusiveRole",
        "InternalRole",
        "ConfigurableRole",
        "EnabledByDefaultRole",
        "ConfigModuleRole",
        "EnabledByDefaultFunctionRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AdditionalRoles'
        QtMocHelpers::EnumData<enum AdditionalRoles>(3, 3, QMC::EnumFlags{}).add({
            {    4, AdditionalRoles::NameRole },
            {    5, AdditionalRoles::DescriptionRole },
            {    6, AdditionalRoles::AuthorNameRole },
            {    7, AdditionalRoles::AuthorEmailRole },
            {    8, AdditionalRoles::LicenseRole },
            {    9, AdditionalRoles::VersionRole },
            {   10, AdditionalRoles::CategoryRole },
            {   11, AdditionalRoles::ServiceNameRole },
            {   12, AdditionalRoles::IconNameRole },
            {   13, AdditionalRoles::StatusRole },
            {   14, AdditionalRoles::WebsiteRole },
            {   15, AdditionalRoles::SupportedRole },
            {   16, AdditionalRoles::ExclusiveRole },
            {   17, AdditionalRoles::InternalRole },
            {   18, AdditionalRoles::ConfigurableRole },
            {   19, AdditionalRoles::EnabledByDefaultRole },
            {   20, AdditionalRoles::ConfigModuleRole },
            {   21, AdditionalRoles::EnabledByDefaultFunctionRole },
        }),
    };
    return QtMocHelpers::metaObjectData<EffectsModel, qt_meta_tag_ZN4KWin12EffectsModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWin::EffectsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin12EffectsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin12EffectsModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KWin12EffectsModelE_t>.metaTypes,
    nullptr
} };

void KWin::EffectsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EffectsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loaded(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EffectsModel::*)()>(_a, &EffectsModel::loaded, 0))
            return;
    }
}

const QMetaObject *KWin::EffectsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWin::EffectsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KWin12EffectsModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KWin::EffectsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KWin::EffectsModel::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
